@@ -6,9 +6,10 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 use Log::Log4perl ':easy';
+use Method::Signatures;
 use SOAP::Lite;
 
 use WWW::SFDC::Apex::ExecuteAnonymousResult;
@@ -21,49 +22,34 @@ has 'uri',
     default=> "http://soap.sforce.com/2006/08/apex";
 
 sub _extractURL {
+    # NB that the // are part of the pattern
     return $_[1]->{serverUrl} =~ s{/u/}{/s/}r;
 }
 
 
 
-sub compileAndTest {
-  my ($self, @names) = @_;
-
-  return $self->_call(
-    'compileAndTest',
-    map {\SOAP::Data->name(classes => $_)} @names
-    );
+sub compileAndTest () {
+  ...
 }
 
 
 sub compileClasses {
-  my ($self, @names) = @_;
-
-  return $self->_call(
-    'compileClasses',
-    SOAP::Data->value(map {SOAP::Data->name(scripts => $_)} @names)
-    );
+  ...
 }
 
 
 sub compileTriggers {
-  my ($self, @names) = @_;
-
-  return $self->_call(
-    'compileTriggers',
-    map {\SOAP::Data->name(classes => $_)} @names
-    );
+  ...
 }
 
 
-sub executeAnonymous {
-  my ($self, $code, %options) = @_;
+method executeAnonymous ($code, :$debug = 1) {
 
-  my ($result, $headers) = $self->_call(
+  my $callResult = $self->_call(
     'executeAnonymous',
     SOAP::Data->name(string => $code),
     (
-      $options{debug}
+      $debug
         ? SOAP::Header->name('DebuggingHeader' => \SOAP::Data->name(
             debugLevel => 'DEBUGONLY'
           ))->uri($self->uri)
@@ -72,19 +58,14 @@ sub executeAnonymous {
   );
 
   return WWW::SFDC::Apex::ExecuteAnonymousResult->new(
-    _result => $result,
-    _headers => $headers
+    _result => $callResult->result,
+    _headers => $callResult->headers
   );
 }
 
 
 sub runTests {
-  my ($self, @names) = @_;
-
-  return $self->_call(
-    'runTests',
-    map {\SOAP::Data->name(classes => $_)} @names
-    );
+  ...
 }
 
 
@@ -104,7 +85,7 @@ WWW::SFDC::Apex - Interface to the salesforce.com Apex SOAP Api
 
 =head1 VERSION
 
-version 0.35
+version 0.37
 
 =head1 METHODS
 
@@ -123,7 +104,14 @@ executeAnonymous call. You must manually check whether this succeeded.
 
 =head2 wsdlToApex
 
-Unimplemented
+=head1 WARNING
+
+The only implemented method from the Apex API is currently executeAnonymous.
+Without a solid use-case for the other methods, I'm not sure what the return
+values of those calls should be.
+
+If you want to implement those calls, please go ahead, constructing results
+as you see fit, and submit a pull request!
 
 =head1 AUTHOR
 
