@@ -5,7 +5,7 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 use List::Util 'first';
 use Log::Log4perl ':easy';
@@ -23,22 +23,20 @@ has 'uri',
 
 sub _extractURL { return $_[1]->{serverUrl} }
 
+
 has 'TYPES',
   is => 'ro',
   lazy => 1,
   default => sub {
     my $self = shift;
-    my ($describe) = $self->session->Metadata->describeMetadata(
-          $self->session->apiVersion
-    );
     +{
       map {
         $_->{directoryName} => $_;
-      } @{$describe->{metadataObjects}}
+      } @{$self->session->Metadata->describeMetadata->{metadataObjects}}
     }
   };
 
-has 'subcomponents',
+has '_subcomponents',
   is => 'ro',
   lazy => 1,
   default => sub {
@@ -52,6 +50,24 @@ has 'subcomponents',
     } values $self->TYPES];
   };
 
+  
+my %_SUBCOMPONENTS = (
+  actionOverrides => 'ActionOverride',
+  alerts => 'WorkflowAlert',
+  businessProcesses => 'BusinessProcess',
+  fieldSets => 'FieldSet',
+  fieldUpdates => 'WorkflowFieldUpdate',
+  fields => 'CustomField',
+  flowActions => 'WorkflowFlowAction',
+  listViews => 'ListView',
+  outboundMessages => 'WorkflowOutboundMessage',
+  recordTypes => 'RecordType',
+  rules => 'WorkflowRule',
+  tasks => 'WorkflowTask',
+  validationRules => 'ValidationRule',
+  webLinks => 'WebLink'
+);
+    
 
 sub needsMetaFile {
   my ($self, $type) = @_;
@@ -86,15 +102,14 @@ sub getDiskName {
 
 sub getName {
   my ($self, $type) = @_;
-  return $type if grep {/$type/} @{$self->subcomponents};
+  return $_SUBCOMPONENTS{$type} if grep {/$type/} keys %_SUBCOMPONENTS;
   LOGDIE "$type is not a recognised type" unless $self->TYPES->{$type};
   return $self->TYPES->{$type}->{xmlName};
 }
 
 
-sub getSubcomponents {
-  my $self = shift;
-  return @{$self->subcomponents};
+sub getSubcomponentsXMLNames {
+  return keys %_SUBCOMPONENTS;
 }
 
 1;
@@ -109,7 +124,31 @@ WWW::SFDC::Constants - Data about SFDC Metadata Components.
 
 =head1 VERSION
 
-version 0.35
+version 0.37
+
+=head1 SYNOPSIS
+
+Provides the methods required for translating on-disk file names and component
+names to forms that the metadata API recognises, and vice-versa.
+
+  WWW::SFDC::Constants->new(
+    session => $session
+  );
+
+OR
+
+  WWW::SFDC::Constants->new(
+    TYPES => $types
+  );
+
+=head1 ATTRIBUTES
+
+=head2 TYPES
+
+A hashref containing the result of the metadataObjects member of a
+describeMetadata result. If this is populated, Constants will not send any API
+calls, so setting this in the constructor with a cached version provides
+offline functionality. If you specify a session, this attribute is optional.
 
 =head1 METHODS
 
@@ -123,7 +162,12 @@ version 0.35
 
 =head2 getName
 
-=head2 getSubcomponents
+When provided with the disk (folder) name for a component type or the node name of a subcomponent,
+provides the Metadata API name for that type.
+
+=head2 getSubcomponentsXMLNames
+
+Returns a list of XML node names for subcomponents.
 
 =head1 AUTHOR
 
