@@ -5,60 +5,67 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
-use XML::Parser;
-use Scalar::Util qw(blessed);
-use List::Util 1.29 qw'first reduce pairmap pairgrep pairfirst';
 use Data::Dumper;
+use List::Util 1.29 qw'first reduce pairmap pairgrep pairfirst';
 use Log::Log4perl ':easy';
+use Method::Signatures;
+use Scalar::Util qw(blessed);
+use XML::Parser;
 
 use Moo;
 
-has 'constants', is => 'ro', required => 1;
-has 'manifest', is => 'rw', default => sub { {} };
-has 'isDeletion', is => 'ro';
+
 has 'apiVersion', is => 'rw', default => '34';
 
 
+has 'constants', is => 'ro', required => 1;
+
+
+has 'isDeletion', is => 'ro';
+
+
+has 'manifest', is => 'rw', default => sub { {} };
+
 # _splitLine($line)
 
 # Takes a string representing a file on disk, such as "email/foo/bar.email-meta.xml",
 # and returns a hash containing the metadata type, folder name, file name, and
 # file extension, excluding -meta.xml.
 
-sub _splitLine {
-  my ($self, $line) = @_;
+method _splitLine ($line) {
+  # we're using '' in lots of regexes to avoid escaping / all over the place
+  # This method could probably be cleaned up by using File::Spec or similar.
 
-  LOGDIE "Called _splitLine with no argument!" unless $line;
+  $line =~ s".*src/"";  # Bin anything up to and including src/.
+  $line =~ s/[\n\r]//g; # Bin any newline characters.
+  $line =~ s"\\"/"g;    # Turn \ into / for cross-platform paths.
 
-  # clean up the line
-  $line =~ s/.*src\///;
-  $line =~ s/[\n\r]//g;
+  my %result = (extension => "");
 
-  my %result = ("extension" => "");
+  ($result{type}) = $line =~ m"^(\w+)/" or LOGDIE "Line $line doesn't have a type.";
 
-  ($result{"type"}) = $line =~ /^(\w+)\//
-    or LOGDIE "Line $line doesn't have a type.";
-  $result{"folder"} = $1
-    if $line =~ /\/(\w+)\//;
+  $result{folder} = $1 if $line =~ m"/(\w+)/";
 
   my $extension = (grep {$_ eq $result{type}} keys $self->constants->TYPES)
-    ? $self->constants->getEnding($result{"type"})
+    ? $self->constants->getEnding($result{type})
     : undef;
 
-  if ($line =~ /\/(\w+)-meta.xml/) {
-    $result{"name"} = $1
+  if ($line =~ m"/(\w+)-meta.xml") {
+    $result{name} = $1
+
   } elsif (!defined $extension) {
-    ($result{"name"}) = $line =~ /\/([^\/]*?)(-meta\.xml)?$/;
+    ($result{name}) = $line =~ m"/([^/]*?)(-meta\.xml)?$";
     # This is because components get passed back from listDeletions with : replacing .
-    $result{"name"} =~ s/:/./;
-  } elsif ($line =~ /\/([^\/]*?)($extension)(-meta\.xml)?$/) {
-    $result{"name"} = $1;
-    $result{"extension"} = $2;
+    $result{name} =~ s":".";
+
+  } elsif ($line =~ m"/([^/]*?)($extension)(-meta\.xml)?$") {
+    $result{name} = $1;
+    $result{extension} = $2;
   }
 
-  LOGDIE "Line $line doesn't have a name." unless $result{"name"};
+  LOGDIE "Line $line doesn't have a name." unless $result{name};
 
   return \%result;
 }
@@ -73,25 +80,31 @@ sub _splitLine {
 # - email/foo/bar.email
 # - email/foo/bar.email-meta.xml
 
-sub _getFilesForLine {
-  my ($self, $line) = @_;
-
+method _getFilesForLine ($line?) {
   return () unless $line;
 
   my %split = %{$self->_splitLine($line)};
 
   return map {"$split{type}/$_"} (
     $split{"folder"}
-    ?(
-      "$split{folder}-meta.xml",
-      "$split{folder}/$split{name}$split{extension}",
-      ($self->constants->needsMetaFile($split{"type"}) ? "$split{folder}/$split{name}$split{extension}-meta.xml" : ())
-     )
-    :(
-      "$split{name}$split{extension}",
-      ($self->constants->needsMetaFile($split{"type"}) ? "$split{name}$split{extension}-meta.xml" : ())
-     )
-   )
+      ? (
+        "$split{folder}-meta.xml",
+        "$split{folder}/$split{name}$split{extension}",
+        (
+          $self->constants->needsMetaFile($split{"type"})
+            ? "$split{folder}/$split{name}$split{extension}-meta.xml"
+            : ()
+        )
+      )
+      : (
+        "$split{name}$split{extension}",
+        (
+          $self->constants->needsMetaFile($split{"type"})
+            ? "$split{name}$split{extension}-meta.xml"
+            : ()
+        )
+      )
+  )
 }
 
 
@@ -100,8 +113,7 @@ sub _getFilesForLine {
 # Returns a list reference to a _deduped version of the list
 # reference passed in.
 
-sub _dedupe {
-  my ($self) = @_;
+method _dedupe {
   my %result;
   for my $key (keys %{$self->manifest}) {
     my %_deduped = map {$_ => 1} @{$self->manifest->{$key}};
@@ -112,8 +124,7 @@ sub _dedupe {
 }
 
 
-sub getFileList {
-  my $self = shift;
+method getFileList {
 
   return map {
     my $type = $self->constants->getDiskName($_);
@@ -130,8 +141,7 @@ sub getFileList {
 }
 
 
-sub add {
-  my ($self, $new) = @_;
+method add ($new) {
 
   if (defined blessed $new and blessed $new eq blessed $self) {
     push @{$self->manifest->{$_}}, @{$new->manifest->{$_}} for keys %{$new->manifest};
@@ -143,8 +153,7 @@ sub add {
 }
 
 
-sub addList {
-  my $self = shift;
+method addList (@_) {
 
   return reduce {$a->add($b)} $self, map {
     TRACE "Adding $_ to manifest";
@@ -162,8 +171,22 @@ sub addList {
 }
 
 
-sub readFromFile {
-  my ($self, $fileName) = @_;
+method readFromFile ($fileName) {
+  # XML::Parser returns a list which consists of
+  #
+  # (
+  #   $attributes,
+  #   $childNodeName, $childNodeElements,
+  #   $childNodeName, $childNodeElements,
+  #   ...
+  # )
+  #
+  # Where each $childNodeElements looks like this too (ie recursive).
+  #
+  # We use splice to remove the $attributes which we assume will be empty,
+  # then use pairmap and pairgrep to find the right nodes to operate on and
+  # transform the data. Finally, we use reduce (from List::Util) to add each
+  # resulting hashref to the current manifest.
 
   return reduce {$a->add($b)} $self, map {+{
     do {
@@ -179,16 +202,15 @@ sub readFromFile {
 }
 
 
-sub writeToFile {
-  my ($self, $fileName) = @_;
+method writeToFile ($fileName) {
   open my $fh, ">", $fileName or LOGDIE "Couldn't open $fileName to write manifest to disk";
   print $fh $self->getXML();
   return $self;
 }
 
 
-sub getXML {
-  my ($self) = @_;
+method getXML {
+  # Ultra-low-tech.
   return join "", (
     "<?xml version='1.0' encoding='UTF-8'?>",
     "<Package xmlns='http://soap.sforce.com/2006/04/metadata'>",
@@ -204,7 +226,6 @@ sub getXML {
    );
 }
 
-
 1;
 
 __END__
@@ -217,7 +238,7 @@ WWW::SFDC::Manifest - Utility functions for Salesforce Metadata API interactions
 
 =head1 VERSION
 
-version 0.35
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -234,6 +255,51 @@ and get a structure suitable for passing into WWW::SFDC::Metadata functions.
     my $HashRef = $Manifest->manifest();
     my $XMLString = $Manifest->getXML();
 
+=head1 ATTRIBUTES
+
+=head2 apiVersion
+
+This apiVersion will be written to the manifest .xml file - defaults to 34.
+Beware that the API version specified in a manifest file overrides the API
+version specified in the endpoint URL.
+
+=head2 constants
+
+A L<WWW::SFDC::Constants> object. If you're working with a session, you'll
+need to pass in the constants from the session. If you're trying to work
+offline, you'll need to create a new Constants object explicitly.
+
+=head2 isDeletions
+
+If set, the manifest will be constructed slightly differently: when you add a
+file inside a folder, such as src/email/myfolder/mytemplate.email, normally
+the manifest will include both the folder and the template. However, when
+deleting, the folder will not be included unless the -meta file is explicitly
+specified, i.e. src/email/myfolder-meta.xml. This is because deleting the
+folder will delete all members of that folder, and that's not normally the
+desired effect.
+
+=head2 manifest
+
+The underlying hash for the Manifest object. This hashref can be passed into a
+call to retrieve(), and a WWW::SFDC::Manifest can also be created with this
+prepopulated, if you already know what it should contain.
+
+This hashref will look like
+
+  {
+    classes => [
+      'myclass',
+      ...
+    ],
+    email => [
+      'myfolder',
+      'myfolder/mytemplate',
+      ...
+    ]
+    ...
+  }
+
 =head1 METHODS
 
 =head2 getFileList(@list)
@@ -265,7 +331,7 @@ Returns the XML representation for this manifest.
 
 =head1 BUGS
 
-Please report any bugs or feature requests at L<https://github.com/alexander-brett/WWW-SFDC/issues>.
+Please report any bugs or feature requests at L<https://github.com/sophos/WWW-SFDC/issues>.
 
 =head1 SUPPORT
 
@@ -273,7 +339,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WWW::SFDC::Manifest
 
-You can also look for information at L<https://github.com/alexander-brett/WWW-SFDC>
+You can also look for information at L<https://github.com/sophos/WWW-SFDC>
 
 =head1 AUTHOR
 
