@@ -5,10 +5,11 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 use Data::Dumper;
 use Log::Log4perl ':easy';
+use Method::Signatures;
 use SOAP::Lite;
 
 use WWW::SFDC::Metadata::DeployResult;
@@ -16,7 +17,6 @@ use WWW::SFDC::Metadata::DeployResult;
 use Moo;
 with "WWW::SFDC::Role::SessionConsumer";
 
-
 has 'uri',
   is => 'ro',
   default => "http://soap.sforce.com/2006/04/metadata";
@@ -26,9 +26,7 @@ sub _extractURL {
 }
 
 
-sub listMetadata {
-
-  my $self = shift; #remaining elements of @_ are queries;
+method listMetadata (@_) {
 
   INFO "Listing Metadata...\t";
 
@@ -37,7 +35,7 @@ sub listMetadata {
 
   # listMetadata can only handle 3 requests at a time, so we chunk them.
   while (my @items = splice @queryData, 0, 3) {
-    push @result, $$_{fileName} for $self->_call('listMetadata', @items);
+    push @result, $$_{fileName} for @{$self->_call('listMetadata', @items)->results};
   }
 
   return @result;
@@ -47,11 +45,9 @@ sub listMetadata {
 # Sets up an asynchronous metadata retrieval request and
 # returns just the id, for checking later. Accepts a manifest.
 
-sub _startRetrieval {
+method _startRetrieval ($manifest) {
   INFO "Starting retrieval";
 
-  my ($self, $manifest) = @_;
-
   # These maps basically preserve the structure passed in,
   # translating it to salesforce's special package.xml structure.
   my @queryData = map {
@@ -64,7 +60,7 @@ sub _startRetrieval {
     } keys %$manifest;
 
 
-  return ($self->_call(
+  return $self->_call(
     'retrieve',
     SOAP::Data->name(
       retrieveRequest => {
@@ -72,7 +68,7 @@ sub _startRetrieval {
       	apiVersion => $self->session->apiVersion(),
       	unpackaged => \SOAP::Data->value(@queryData)
       })
-   ) )[0]->{id};
+   )->result->{id};
 
 }
 
@@ -80,14 +76,12 @@ sub _startRetrieval {
 # undef unless there's something to give back, in which case it
 # returns the base64 encoded zip file from the response.
 
-sub _checkRetrieval {
-  my ($self, $id) = @_;
-  LOGDIE "No ID was passed in!" unless $id;
+method _checkRetrieval ($id) {
 
-  my ($result) = $self->_call(
+  my $result = $self->_call(
     'checkRetrieveStatus',
     SOAP::Data->name("asyncProcessId" => $id)
-   );
+   )->result;
 
   INFO "Status:" . $$result{status};
 
@@ -97,34 +91,29 @@ sub _checkRetrieval {
 }
 
 
-sub retrieveMetadata {
-
-  my ($self, $manifest) = @_;
-  LOGDIE "This method must be called with a manifest" unless $manifest;
+method retrieveMetadata ($manifest) {
 
   my $requestId = $self->_startRetrieval($manifest);
-
   my $result;
 
   do { $self->_sleep() } until $result = $self->_checkRetrieval($requestId);
 
   return $result;
+
 }
 
 
 #Check up on an async deployment request. Returns 1 when complete.
-sub _checkDeployment {
-  my ($self, $id, $previous) = @_;
-  LOGDIE "No ID was passed in" unless $id;
+method _checkDeployment ($id, $previous?) {
 
-  my ($request, $headers) = $self->_call(
+  my $callResult = $self->_call(
       'checkDeployStatus',
       SOAP::Data->name("id" => $id),
       SOAP::Data->name("includeDetails" => "true")
-    );
+    )->result;
 
   my $result = WWW::SFDC::Metadata::DeployResult->new(
-    result => $request
+    result => $callResult
   );
 
   if (scalar (my @errors = (
@@ -134,14 +123,12 @@ sub _checkDeployment {
     WARN Dumper \@errors;
   }
 
-
   return $result
 }
 
-sub deployMetadata {
-  my ($self, $zip, $deployOptions) = @_;
+method deployMetadata ($zip, $deployOptions?) {
 
-  my ($result) = $self->_call(
+  my $result = $self->_call(
     'deploy',
     SOAP::Data->name( zipfile => $zip),
     (
@@ -149,7 +136,7 @@ sub deployMetadata {
         ? SOAP::Data->name(DeployOptions=>$deployOptions)
         : ()
     )
-   );
+   )->result;
 
   INFO "Deployment ID: $$result{id}";
 
@@ -165,26 +152,23 @@ sub deployMetadata {
 }
 
 
-sub deployRecentValidation {
-  my ($self, $id) = @_;
-
+method deployRecentValidation ($id) {
   chomp $id;
 
   return WWW::SFDC::Metadata::DeployResult->new(
     result => $self->_call(
       'deployRecentValidation',
       SOAP::Data->name(validationID => $id)
-    )
+    )->result
   );
 }
 
-sub describeMetadata {
-  my ($self) = @_;
 
+method describeMetadata {
   return $self->_call(
     'describeMetadata',
     SOAP::Data->name(apiVersion => $self->session->apiVersion)
-   );
+   )->result;
 }
 
 1;
@@ -199,7 +183,7 @@ WWW::SFDC::Metadata - Interface to the Salesforce.com Metadata API
 
 =head1 VERSION
 
-version 0.35
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -227,16 +211,18 @@ For more in-depth examples, see t/WWW/SFDC/Metadata.t
 
 =head1 METHODS
 
-=head2 listMetadata @queries
+=head2 listMetadata(@queries)
 
 Accepts a list of types and folders, such as
 
+$session->Metadata->listMetadata(
    {type => "CustomObject"},
    {type => "Report", folder => "FooReports"}
+);
 
 and generates a list of file names suitable for turning into a WWW::SFDC::Manifest.
 
-=head2 retrieveMetadata $manifest
+=head2 retrieveMetadata($manifest)
 
 Sets up a retrieval from then checks it until done. Returns the
 same data as checkRetrieval. Requires a manifest of the form:
@@ -247,6 +233,10 @@ same data as checkRetrieval. Requires a manifest of the form:
    "Profile" => ["*"]
   };
 
+This method handles starting the retrieval, and polls until it completes, then
+returns the a string which is the base64 encoded .zip file containing the
+data.
+
 =head2 deployMetadata $zipString, \%deployOptions
 
 Takes a base64 zip file and deploys it. Deploy options will be
@@ -260,9 +250,14 @@ operation. You must manually check whether this succeeded!
 
 Calls deployRecentValidation with your successfully-validated deployment.
 
+=head2 describeMetadata
+
+Returns a describeMetadataResult hashref as specified by Salesforce.com.
+L<WWW::SFDC::Constants> consumes this object to provide utility methods.
+
 =head1 BUGS
 
-Please report any bugs or feature requests at L<https://github.com/alexander-brett/WWW-SFDC/issues>.
+Please report any bugs or feature requests at L<https://github.com/sophos/WWW-SFDC/issues>.
 
 =head1 SUPPORT
 
@@ -270,7 +265,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WWW::SFDC::Metadata
 
-You can also look for information at L<https://github.com/alexander-brett/WWW-SFDC>
+You can also look for information at L<https://github.com/sophos/WWW-SFDC>
 
 =head1 AUTHOR
 
