@@ -4,7 +4,7 @@ package WWW::SFDC::Metadata::DeployResult;
 use strict;
 use warnings;
 
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 use Log::Log4perl ':easy';
 
@@ -15,25 +15,32 @@ use overload
 
 use Moo;
 
+
 has 'id',
   is => 'ro',
   lazy => 1,
   builder => sub {return $_[0]->result->{id}};
 
+
 has 'success',
   is => 'ro',
   lazy => 1,
   builder => sub {return $_[0]->result->{status} eq 'Succeeded'};
 
+
 has 'complete',
   is => 'ro',
   lazy => 1,
-  builder => sub {return $_[0]->result->{status} !~ /Queued|Pending|InProgress/;};
+  builder => sub {
+    return $_[0]->result->{status} !~ /Queued|Pending|InProgress/;
+  };
+
 
 has 'result',
   is => 'ro',
   required => 1;
 
+
 has 'testFailures',
   is => 'ro',
   lazy => 1,
@@ -51,6 +58,7 @@ has 'testFailures',
       : [$self->result->{details}->{runTestResult}->{failures}]
   };
 
+
 has 'componentFailures',
   is => 'ro',
   lazy => 1,
@@ -78,6 +86,7 @@ sub BUILD {
     );
 }
 
+
 sub testFailuresSince {
   my ($self, $previous) = @_;
   return ()
@@ -105,6 +114,7 @@ sub testFailuresSince {
   return @newResults
 }
 
+
 sub componentFailuresSince {
   my ($self, $previous) = @_;
   return ()
@@ -143,7 +153,73 @@ WWW::SFDC::Metadata::DeployResult - Container for Salesforce Metadata API Deploy
 
 =head1 VERSION
 
-version 0.35
+version 0.37
+
+=head1 DESCRIPTION
+
+L<WWW::SFDC::Metadata>->Deploy returns a DeployResult in order to provide rich
+ability for handling different categories of errors, including categorised test
+results and component failures.
+
+It is overloaded such that when stringified it returns the deployment ID,
+because that's the most important element, and it enables chaining with
+DeployRecentValidation.
+
+You probably will only consume this, rather than explicitly creating it.
+
+=head1 ATTRIBUTES
+
+=head2 id
+
+The deployment ID. When stringified, this is the object's value.
+
+=head2 success
+
+A boolean representing whether the deployment's status is 'Succeeded'.
+
+=head2 complete
+
+A boolean representing whether the deployment is in any complete status,
+successful or otherwise.
+
+=head2 result
+
+The 'result' element of a SOAP::SOM returned from a Salesforce Deploy call.
+This is used for the generation of all other attributes.
+
+=head2 testFailures
+
+An arrayref of testResults, sorted by class name and method name.
+
+=head2 testFailures
+
+An arrayref of failed components, sorted by file name and component name.
+
+=head1 METHODS
+
+=head2 testFailuresSince($previous)
+
+Here, $previous is another WWW::SFDC::Metadata::DeployResult. This attribute
+holds all failures that are new in this result compared to the previous one.
+This is useful for providing a running commentary on what's failed so far.
+
+=head2 componentFailuresSince($previous)
+
+Here, $previous is another WWW::SFDC::Metadata::DeployResult. This attribute
+holds all failures that are new in this result compared to the previous one.
+This is useful for providing a running commentary on what's failed so far.
+
+=head1 BUGS
+
+Please report any bugs or feature requests at L<https://github.com/sophos/WWW-SFDC/issues>.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc WWW::SFDC::Metadata::DeployResult
+
+You can also look for information at L<https://github.com/sophos/WWW-SFDC>
 
 =head1 AUTHOR
 
