@@ -5,25 +5,24 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 use Data::Dumper;
 use Log::Log4perl ':easy';
+use Method::Signatures;
 use Scalar::Util 'blessed';
 use SOAP::Lite;
 
 use Moo;
 with "WWW::SFDC::Role::SessionConsumer", "WWW::SFDC::Role::CRUD";
 
-
 has 'uri',
   is => 'ro',
   default => "urn:partner.soap.sforce.com";
 
 sub _extractURL { return $_[1]->{serverUrl} }
 
-sub _prepareSObjects {
-  my $self = shift;
+method _prepareSObjects (@_) {
   # prepares an array of objects for an update or insert call by converting
   # it to an array of SOAP::Data
 
@@ -49,14 +48,12 @@ sub _prepareSObjects {
 }
 
 
-sub setPassword {
-  my ($self, %params) = @_;
-  LOGDIE "You must provide an Id and Password" unless $params{Id} and $params{Password};
-  INFO "Setting password for user $params{Id}";
+method setPassword (:$Id!, :$Password!){
+  INFO "Setting password for user $Id";
   return $self->_call(
     'setPassword',
-    SOAP::Data->name(userID => $params{Id}),
-    SOAP::Data->name(password => $params{Password}),
+    SOAP::Data->name(userID => $Id),
+    SOAP::Data->name(password => $Password),
    );
 }
 
@@ -72,7 +69,7 @@ WWW::SFDC::Partner - Interface to the Salesforce.com Partner API
 
 =head1 VERSION
 
-version 0.35
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -88,6 +85,8 @@ version 0.35
         map { $_->{field} =~ s/baz/bat/ } @objects
     );
 
+This module consumes L<WWW::SFDC::Role::CRUD>.
+
 =head1 METHODS
 
 =head2 setPassword
@@ -96,7 +95,7 @@ version 0.35
 
 =head1 BUGS
 
-Please report any bugs or feature requests at L<https://github.com/alexander-brett/WWW-SFDC/issues>.
+Please report any bugs or feature requests at L<https://github.com/sophos/WWW-SFDC/issues>.
 
 =head1 SUPPORT
 
@@ -104,7 +103,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WWW::SFDC::Partner
 
-You can also look for information at L<https://github.com/alexander-brett/WWW-SFDC>
+You can also look for information at L<https://github.com/sophos/WWW-SFDC>
 
 =head1 AUTHOR
 
