@@ -5,11 +5,12 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 use Data::Dumper;
 use List::NSect 'spart';
 use Log::Log4perl ':easy';
+use Method::Signatures;
 use Scalar::Util 'blessed';
 use SOAP::Lite;
 
@@ -17,20 +18,18 @@ use Moo::Role;
 requires qw'_prepareSObjects';
 
 
-sub _queryMore {
-  my ($self, $locator) = @_;
+method _queryMore ($locator) {
   return $self->_call(
     'queryMore',
     SOAP::Data->name(queryLocator => $locator),
-  );
+  )->result;
 }
 
 # Extract the results from a $request. This handles the case
 # where there is only one result, as well as 0 or more than 1.
 # They require different handling because in the 1 case, you
 # can't handle it as an array
-sub _getQueryResults {
-  my ($self, $request) = @_;
+method _getQueryResults ($request) {
   TRACE Dumper $request;
   return ref $request->{records} eq 'ARRAY'
     ? map {$self->_cleanUpSObject($_)} @{$request->{records}}
@@ -39,8 +38,7 @@ sub _getQueryResults {
 
 # Unbless an SObject, and de-duplicate the ID field - SFDC
 # duplicates the ID, which is interpreted as an arrayref!
-sub _cleanUpSObject {
-  my ($self, $obj) = @_;
+method _cleanUpSObject ($obj) {
   return () unless $obj;
   my %copy = %$obj; # strip the class from $obj
   $copy{Id} = $copy{Id}->[0] if $copy{Id} and ref $copy{Id} eq "ARRAY";
@@ -63,37 +61,30 @@ sub _cleanUpSObject {
 }
 
 # Chain together calls to _queryMore() and handle the results.
-sub _completeQuery {
-  my ($self, %params) = @_;
+method _completeQuery (
+  :$query!,
+  :$method!,
+  :$callback = sub {state @results; push @results, @_; return @results}
+) {
 
-  LOGDIE "You must provide a query string!" unless $params{query};
-  INFO "Executing SOQL query: $params{query}";
+  INFO "Executing SOQL query: $query";
 
-  my ($request, $headers) = $self->_call(
-    $params{method},
-    SOAP::Data->name(queryString => $params{query})
-  );
+  my $result = $self->_call(
+    $method,
+    SOAP::Data->name(queryString => $query)
+  )->result;
 
-
-  my $callback = $params{callback} || sub {
-    TRACE Dumper \@_;
-    state @results;
-    push @results, @_;
-    return @results;
-  };
-
-  my @result = $callback->($self->_getQueryResults($request));
-  until ($request->{done} eq 'true') {
+  my @results = $callback->($self->_getQueryResults($result));
+  until ($result->{done} eq 'true') {
     $self->_sleep();
-    $request = $self->_queryMore($request->{queryLocator});
-    @result = $callback->($self->_getQueryResults($request));
+    $result = $self->_queryMore($result->{queryLocator});
+    @results = $callback->($self->_getQueryResults($result));
   }
 
-  return @result;
+  return @results;
 }
 
-sub query {
-  my ($self, $params) = @_;
+method query ($params) {
   return $self->_completeQuery(
     ref $params
       ? %$params
@@ -102,8 +93,7 @@ sub query {
   );
 }
 
-sub queryAll {
-  my ($self, $params) = @_;
+method queryAll ($params) {
   return $self->_completeQuery(
     ref $params
       ? %$params
@@ -114,69 +104,96 @@ sub queryAll {
 }
 
 
-sub create {
-  my $self = shift;
-
+method create (@_) {
   return map {
-    $self->_call(
+    @{$self->_call(
       'create',
       $self->_prepareSObjects(@$_)
-    );
+    )->results};
   } spart 200, @_;
 }
 
 
-sub update {
-  my $self = shift;
+method update (@_) {
 
   TRACE "Objects for update" => \@_;
   INFO "Updating objects";
 
-  return $self->_call(
+  return @{$self->_call(
     'update',
     $self->_prepareSObjects(@_)
-   );
+   )->results};
 }
 
 
-sub delete {
-    my $self = shift;
+method delete (@_) {
 
     DEBUG "IDs for deletion" => \@_;
     INFO "Deleting objects";
 
-    return $self->_call(
+    return @{$self->_call(
         'delete',
         map {SOAP::Data->name('ids' => $_)} @_
-    );
+    )->results};
 }
 
 
-sub undelete {
-    my $self = shift;
+method undelete (@_) {
 
     DEBUG "IDs for undelete" => \@_;
     INFO "Deleting objects";
 
-    return $self->_call(
+    return @{$self->_call(
         'undelete',
         map {SOAP::Data->name('ids' => $_)} @_
-    );
+    )->results};
 }
 
 
-sub retrieve {
-    my $self = shift;
+method retrieve (@_) {
 
     DEBUG "IDs for retrieve" => \@_;
     INFO "Retrieving objects";
 
-    return $self->_call(
+    return @{$self->_call(
         'retrieve',
         map {SOAP::Data->name('ids' => $_)} @_
-    );
+    )->results};
 }
 
+
+
+
+## see:
+# http://stackoverflow.com/questions/7070553/soapdatabuilder-remove-xsinil-true-when-no-value-provided
+# http://mkweb.bcgsc.ca/intranet/perlbook/perlnut/ch14_02.htm#INDEX-1888
+# http://search.cpan.org/~byrne/SOAP-Lite-0.65_5/lib/SOAP/Serializer.pm#as_TypeName_SUBROUTINE_REQUIREMENTS
+
+method SOAP::Serializer::as_nonil ($value, $name, $type, $attr) {
+    delete $attr->{'xsi:nil'};
+    return [ $name, $attr, $value ];
+}
+
+method describeGlobal () {
+
+  return $self->_call(
+    SOAP::Data->name("describeGlobal")
+      ->uri($self->uri)
+      ->type('nonil')
+  )->result;
+}
+
+
+method describeSObjects (@names) {
+
+  return map {
+    $self->_call(
+      'describeSObjects',
+      @$_
+    )->result;
+  } spart 100, @names;
+
+}
 1;
 
 __END__
@@ -189,7 +206,12 @@ WWW::SFDC::Role::CRUD - Shared methods between partner and tooling APIs
 
 =head1 VERSION
 
-version 0.35
+version 0.37
+
+=head1 DESCRIPTION
+
+WWW::SFDC::Role::CRUD provides standard SObject manipulation methods which are
+shared between the Partner and Tooling APIs.
 
 =head1 METHODS
 
@@ -220,8 +242,8 @@ This has the same additional behaviour as query().
 =head2 create
 
   say "$$_{id}:\t$$_{success}" for WWW::SFDC->new(...)->Partner->create(
-    {type => 'thing', Id => 'foo', Field__c => 'bar', Name => 'baz'}
-    {type => 'otherthing', Id => 'bam', Field__c => 'bas', Name => 'bat'}
+    {type => 'thing', Field__c => 'bar', Name => 'baz'}
+    {type => 'otherthing', Field__c => 'bas', Name => 'bat'}
   );
 
 Create chunks your SObjects into 200s before calling create(). This means that if
@@ -252,9 +274,18 @@ Returns an array that looks like [{success => 1, id => 'id'}, {}...] with LOWERC
 
 Retrieves SObjects by ID. Not to be confused with the metadata retrieve method.
 
+=head2 describeGlobal
+
+Lists SObjects available through this API.
+
+=head2 describeSObjects
+
+Unimplemented
+
 =head1 BUGS
 
-Please report any bugs or feature requests at L<https://github.com/alexander-brett/WWW-SFDC/issues>.
+Please report any bugs or feature requests at
+L<https://github.com/sophos/WWW-SFDC/issues>.
 
 =head1 SUPPORT
 
@@ -262,7 +293,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WWW::SFDC::Role::CRUD
 
-You can also look for information at L<https://github.com/alexander-brett/WWW-SFDC>
+You can also look for information at L<https://github.com/sophos/WWW-SFDC>
 
 =head1 AUTHOR
 
