@@ -5,18 +5,19 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 use Moo::Role;
 use Module::Loaded;
 
-
 requires qw'_extractURL';
 
+
 has 'session',
   is => 'ro',
   required => 1;
 
+
 has 'url',
   is => 'ro',
   lazy => 1,
@@ -27,17 +28,14 @@ sub _buildURL {
   return $self->_extractURL($self->session->loginResult());
 }
 
+
 sub _call {
   my $self = shift;
-  my $req = $self->session->call(
+  return $self->session->call(
     $self->url(),
     $self->uri(),
     @_
   );
-
-  return $req->result(),
-    (defined $req->paramsout() ? $req->paramsout() : ()),
-    (defined $req->headers() ? $req->headers() : ());
 }
 
 sub _sleep {
@@ -57,7 +55,7 @@ WWW::SFDC::Role::SessionConsumer - Provides a transparent interface to WWW::SFDC
 
 =head1 VERSION
 
-version 0.35
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -85,9 +83,30 @@ version 0.35
 
     1;
 
+=head1 ATTRIBUTES
+
+=head2 session
+
+This is a WWW::SFDC object, and is required when this module is constructed.
+
+=head2 url
+
+The API endpoint URL for the consuming module. For instance, for the metadata
+API, this will contain C</m/>, and for the tooling API will contain C</T/>.
+This is constructed using the _extractURL method in the consuming object,
+which is required.
+
+=head1 METHODS
+
+=head2 _call
+
+The consuming class can use C<$self->_call(@params);> - this will handle
+calling the underlying session with the correct URI and URL. The URI is
+defined in the  consuming class.
+
 =head1 BUGS
 
-Please report any bugs or feature requests at L<https://github.com/alexander-brett/WWW-SFDC/issues>.
+Please report any bugs or feature requests at L<https://github.com/sophos/WWW-SFDC/issues>.
 
 =head1 SUPPORT
 
@@ -95,7 +114,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WWW::SFDC::Role::Session
 
-You can also look for information at L<https://github.com/alexander-brett/WWW-SFDC>
+You can also look for information at L<https://github.com/sophos/WWW-SFDC>
 
 =head1 AUTHOR
 
