@@ -5,7 +5,7 @@ use 5.12.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 use Log::Log4perl ':easy';
 use Scalar::Util 'blessed';
@@ -13,7 +13,6 @@ use Scalar::Util 'blessed';
 use Moo;
 with 'WWW::SFDC::Role::SessionConsumer', 'WWW::SFDC::Role::CRUD';
 
-
 has 'uri',
   is => 'ro',
   default => 'urn:tooling.soap.sforce.com';
@@ -22,7 +21,6 @@ sub _extractURL {
   return $_[1]->{serverUrl} =~ s{/u/}{/T/}r;
 }
 
-
 sub _prepareSObjects {
   my $self = shift;
   # prepares an array of objects for an update or insert call by converting
@@ -51,16 +49,6 @@ sub _prepareSObjects {
 }
 
 
-sub describeGlobal {
-  ...
-}
-
-
-sub describeSObjects {
-  ...
-}
-
-
 sub executeAnonymous {
   my ($self, $code, %options) = @_;
   my $result = $self->_call(
@@ -69,7 +57,7 @@ sub executeAnonymous {
     $options{debug} ? SOAP::Header->name('DebuggingHeader' => \SOAP::Data->name(
         debugLevel => 'DEBUGONLY'
       )) : (),
-   );
+   )->result;
 
   LOGDIE "ExecuteAnonymous failed to compile: " . $result->{compileProblem}
     if $result->{compiled} eq "false";
@@ -87,14 +75,14 @@ sub runTests {
   return $self->_call(
     'runTests',
     map {\SOAP::Data->name(classes => $_)} @names
-  );
+  )->result;
 }
 
 
 sub runTestsAsynchronous {
   my ($self, @ids) = @_;
 
-  return $self->_call('runTestsAsynchronous', join ",", @ids);
+  return $self->_call('runTestsAsynchronous', join ",", @ids)->result;
 }
 
 1;
@@ -109,7 +97,7 @@ WWW::SFDC::Tooling - Interface to the Salesforce.com Tooling API
 
 =head1 VERSION
 
-version 0.35
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -121,14 +109,10 @@ version 0.35
 
 Note that $URL is the _login_ URL, not the Tooling API endpoint URL - which gets calculated internally.
 
+This module consumes L<WWW::SFDC::Role::CRUD>.
+
 =head1 METHODS
 
-=head2 create
-
-=head2 describeGlobal
-
-=head2 describeSObjects
-
 =head2 executeAnonymous
 
     $client->Tooling->executeAnonymous("system.debug(1);")
@@ -137,11 +121,36 @@ Note that $URL is the _login_ URL, not the Tooling API endpoint URL - which gets
 
   $client->Tooling->runTests('name','name2');
 
+returns a RunTestResult hash which looks like:
+
+{
+  successes => [{
+      name => 'MyTest',
+      id => '...',
+      namespace => undef,
+      time => 123, #time in MS
+      methodName => 'something'
+    },
+    ...
+  ],
+  failures => [{...}]
+  totalTime => 1234,
+  numFailures => 3,
+  numTestsRun => 4,
+  codeCoverage => [
+    # HUGE LIST OF HUGH HASHREFS GOES HERE.
+  ]
+
+}
+
 =head2 runTestsAsynchronous
 
+Takes a list of IDs of test classes.
+Returns the ID of the enqueued test run.
+
 =head1 BUGS
 
-Please report any bugs or feature requests at L<https://github.com/alexander-brett/WWW-SFDC/issues>.
+Please report any bugs or feature requests at L<https://github.com/sophos/WWW-SFDC/issues>.
 
 =head1 SUPPORT
 
@@ -149,7 +158,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WWW::SFDC::Tooling
 
-You can also look for information at L<https://github.com/alexander-brett/WWW-SFDC>
+You can also look for information at L<https://github.com/sophos/WWW-SFDC>
 
 =head1 AUTHOR
 
